Development image for wger - Base image
===================================================
This is the base image for some of the other wger images and offers no
functionality, it's only use is to provide some common dependencies.

If you want to develop, try either ``wger/devel`` oder ``wger/devel-fedora``.


Contact
-------

Feel free to contact us if you found this useful or if there was something that
didn't behave as you expected. We can't fix what we don't know about, so please
report liberally. If you're not sure if something is a bug or not, feel free to
file a bug anyway.

* gitter: <https://gitter.im/wger-project/wger>
* issue tracker: <https://github.com/wger-project/wger/issues>
* twitter: <https://twitter.com/wger_de>
* mailing list: <https://groups.google.com/group/wger> / wger@googlegroups.com, no registration needed

Sources
-------

All the code and the content is freely available:

* Main repository: <https://github.com/wger-project/wger>

Licence
-------

The application is licenced under the Affero GNU General Public License 3 or
later (AGPL 3+).

The initial exercise and ingredient data is licensed additionally under one of
the Creative Commons licenses, see the individual exercises for more details.

The documentation is released under a CC-BY-SA either version 4 of the License,
or (at your option) any later version.

Some images where taken from Wikipedia, see the SOURCES file in their respective
folders for more details.
